@@ -2,6 +2,9 @@ package Imager::Transform;
 use strict;
 use Imager;
 use Imager::Expr::Assem;
+use vars qw($VERSION);
+
+$VERSION = "1.005";
 
 my %funcs =
   (
@@ -494,8 +497,18 @@ transformation.
 Returns a list of input image descriptions, or the number of them,
 depending on content.
 
-The list contains hashrefs, which current contain only one member,
-desc, a description of the use of the input image.
+The list contains hash references, which current contain only one
+member, C<desc>, a description of the use of the input image.
+
+=item $tran->constants
+
+Returns a list of names of constants that can be set for the
+transformation.
+
+=item $tran->constants($name, $name, ...)
+
+Returns a hashref for each named constant, which contains the default
+in key C<default> and a description in key C<desc>.
 
 =item my $out = $tran->transform(\%opts, \%constants, @imgs)
 
@@ -516,6 +529,6 @@ Needs more transformations.
 
 =head1 SEE ALSO
 
-Imager(3), transform.perl
+Imager(3), F<transform.perl>
 
 =cut
